httpTokens property
The state of token usage for your instance metadata requests. If the
parameter is not specified in the request, the default state is
optional.
If the state is optional, you can choose to retrieve instance
metadata with or without a signed token header on your request. If you
retrieve the IAM role credentials without a token, the version 1.0 role
credentials are returned. If you retrieve the IAM role credentials using a
valid signed token, the version 2.0 role credentials are returned.
If the state is required, you must send a signed token header
with any instance metadata retrieval requests. In this state, retrieving the
IAM role credentials always returns the version 2.0 credentials; the version
1.0 credentials are not available.
Implementation
final InstanceMetadataHttpTokensState? httpTokens;